"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Provider = void 0;
/**
 * Internally all InjectableIds are mapped to an abstract Provider<T>.
 * A Provider may choose to return a singleton or a new value each time it is queried.
 */
class Provider {
    constructor() {
    }
    /**
     * Base method to initialize the state of this Provider *if* (and only if) it has been configured as a Singleton.
     * If this Provider has not been configured as a singleton, this method is essentially a noop that returns undefined.
     *
     * @param asyncOnly This default implementation ignores this parameter.
     * @returns A completion Promise if initialization requires asynchronicity, otherwise the return value is undefined.
     */
    resolveIfSingleton(asyncOnly) {
        if (this.singleton === null) {
            const s = this.provideAsState();
            if (s.pending)
                return s.promise;
            else if (s.rejected)
                return Promise.reject(s.rejected);
        }
        return undefined;
    }
}
exports.Provider = Provider;
//# sourceMappingURL=provider.js.map